Ext.onReady(function(){

    Ext.define('User', {
        extend : 'Ext.data.Model',
        fields : [ 
        'id',
        'name',{
            mapping : 'email',
            name : 'email',
            type : 'string',
        }, {
            mapping : function(r){
                return r.url;
                //return Ext.util.Format.htmlEncode(r.url);
            },
            name : 'url',
            type : 'string'
        }],
    });

    Ext.define('Users', {
        extend : 'Ext.data.Store',
        model : 'User',
        autoLoad : true,

        proxy : {
            type : 'ajax',
            api : {
                read : 'data/users.json'
            },
            reader : {
                type : 'json',
                root : 'users',
                successProperty : 'success',
            }
        }
    });

    var users = Ext.create('Users',{});

    Ext.define('Regex', {
        singleton : true,
        maskNumber: /[0-9\.]/,
        regexNumber: /^[0-9]+(?:\.[0-9]+)?$/,
        regexEmail: /[\w\-\._\+%]+@(?:[\w-]+\.)+[\w]{2,6}$/,
        regexPhone : /^(\(?(\d{3})\)?\s?-?\s?(\d{3})\s?-?\s?(\d{4}))$/,
        regexDate : /^(0[1-9]|1[012])[- \/.](0[1-9]|[12][0-9]|3[01])[- \/.](19|20)\d\d$/
    });

    Ext.create('Ext.container.Viewport',{
        items : [{
            xtype : 'grid',
            title : 'All users',
            store : users,
            columns : [{
                header : 'name',
                dataIndex : 'name',
                flex : 1
            }, {
                header : 'email',
                dataIndex : 'email',
                flex : 1
            }, {
                header : 'url',
                dataIndex : 'url',
                flex : 1,
                renderer : function( aValue, aMeta, aRecord ){
                    aMeta.style = "color: #FF0000;";
                    return Ext.util.Format.htmlEncode( aValue );
                }
            }]
        },{
            xtype : 'form',
            cls : 'form-user',
            requires : ['Regex'],
            items : [{
                xtype : 'textfield',
                name : 'number',
                fieldname : 'number',
                maskRe: Regex.maskNumber,
                regex: Regex.regexNumber
            },{
                xtype : 'textfield',
                name : 'email',
                fieldname : 'email',
                regex: Regex.regexEmail
            },{
                xtype : 'textfield',
                name : 'phone',
                fieldname : 'phone',
                regex: Regex.regexPhone
            },{
                xtype : 'textfield',
                name : 'date',
                fieldname : 'date',
                regex: Regex.regexDate
            }],
            buttons: [{
                text: 'Submit',
                handler: function() {
                    var form = this.up('form').getForm();
                    if (form.isValid()) {
                        console.log('form valid');
                        form.submit({
                            method: 'POST',
                            url: 'http://localhost:3000/csrf', 
                            success: function(form, action) {
                                console.log('success ajax');
                            },
                            failure: function(form, action) {
                                switch (action.failureType) {
                                    case Ext.form.Action.CLIENT_INVALID :
                                        Ext.Msg.alert('Failure', 'Form fields may not be submitted with invalid values');
                                        break;
                                    case Ext.form.Action.CONNECT_FAILURE :
                                        Ext.Msg.alert('Failure', 'Ajax communication failed');
                                        break;
                                    case Ext.form.Action.SERVER_INVALID :
                                        Ext.Msg.alert('Failure', action.result.msg);
                                }
                            }
                        });
                    }else{
                        console.log('form not valid');
                    }
                }
            },{
                text: 'Reset',
                handler: function() {
                    this.up('form').getForm().reset();
                } 
            }]
        }]
    });
});

